@@ -50,7 +50,7 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:BOXED (/usr/src/ports/caja/caja-1.10.3-1.x86_64/src/caja-1.10.3/eel/eel-marshal.list:1) */
+/* BOOLEAN:BOXED (/usr/src/ports/caja/caja-1.18.2-1.i686/src/caja-1.18.2/eel/eel-marshal.list:1) */
 void
 eel_marshal_BOOLEAN__BOXED (GClosure     *closure,
                             GValue       *return_value G_GNUC_UNUSED,
@@ -62,9 +62,9 @@ eel_marshal_BOOLEAN__BOXED (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__BOXED) (gpointer     data1,
                                                    gpointer     arg_1,
                                                    gpointer     data2);
-  register GMarshalFunc_BOOLEAN__BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -89,7 +89,7 @@ eel_marshal_BOOLEAN__BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:ENUM,INT (/usr/src/ports/caja/caja-1.10.3-1.x86_64/src/caja-1.10.3/eel/eel-marshal.list:2) */
+/* VOID:ENUM,INT (/usr/src/ports/caja/caja-1.18.2-1.i686/src/caja-1.18.2/eel/eel-marshal.list:2) */
 void
 eel_marshal_VOID__ENUM_INT (GClosure     *closure,
                             GValue       *return_value G_GNUC_UNUSED,
@@ -102,9 +102,9 @@ eel_marshal_VOID__ENUM_INT (GClosure     *closure,
                                                gint         arg_1,
                                                gint         arg_2,
                                                gpointer     data2);
-  register GMarshalFunc_VOID__ENUM_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__ENUM_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -126,7 +126,7 @@ eel_marshal_VOID__ENUM_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,INT,BOOLEAN (/usr/src/ports/caja/caja-1.10.3-1.x86_64/src/caja-1.10.3/eel/eel-marshal.list:3) */
+/* VOID:ENUM,INT,BOOLEAN (/usr/src/ports/caja/caja-1.18.2-1.i686/src/caja-1.18.2/eel/eel-marshal.list:3) */
 void
 eel_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                     GValue       *return_value G_GNUC_UNUSED,
@@ -140,9 +140,9 @@ eel_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                                        gint         arg_2,
                                                        gboolean     arg_3,
                                                        gpointer     data2);
-  register GMarshalFunc_VOID__ENUM_INT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__ENUM_INT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -165,48 +165,7 @@ eel_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT,INT,INT (/usr/src/ports/caja/caja-1.10.3-1.x86_64/src/caja-1.10.3/eel/eel-marshal.list:4) */
-void
-eel_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
-                                   GValue       *return_value G_GNUC_UNUSED,
-                                   guint         n_param_values,
-                                   const GValue *param_values,
-                                   gpointer      invocation_hint G_GNUC_UNUSED,
-                                   gpointer      marshal_data)
-{
-  typedef void (*GMarshalFunc_VOID__INT_INT_INT_INT) (gpointer     data1,
-                                                      gint         arg_1,
-                                                      gint         arg_2,
-                                                      gint         arg_3,
-                                                      gint         arg_4,
-                                                      gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT_INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
-
-  g_return_if_fail (n_param_values == 5);
-
-  if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-      data1 = closure->data;
-      data2 = g_value_peek_pointer (param_values + 0);
-    }
-  else
-    {
-      data1 = g_value_peek_pointer (param_values + 0);
-      data2 = closure->data;
-    }
-  callback = (GMarshalFunc_VOID__INT_INT_INT_INT) (marshal_data ? marshal_data : cc->callback);
-
-  callback (data1,
-            g_marshal_value_peek_int (param_values + 1),
-            g_marshal_value_peek_int (param_values + 2),
-            g_marshal_value_peek_int (param_values + 3),
-            g_marshal_value_peek_int (param_values + 4),
-            data2);
-}
-
-/* VOID:OBJECT,POINTER (/usr/src/ports/caja/caja-1.10.3-1.x86_64/src/caja-1.10.3/eel/eel-marshal.list:5) */
+/* VOID:OBJECT,POINTER (/usr/src/ports/caja/caja-1.18.2-1.i686/src/caja-1.18.2/eel/eel-marshal.list:4) */
 void
 eel_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                   GValue       *return_value G_GNUC_UNUSED,
@@ -219,9 +178,9 @@ eel_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                      gpointer     arg_1,
                                                      gpointer     arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
