@@ -50,7 +50,7 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:VOID (/usr/src/ports/caja/caja-1.10.3-1.x86_64/src/caja-1.10.3/src/file-manager/fm-marshal.list:1) */
+/* BOOLEAN:VOID (/usr/src/ports/caja/caja-1.18.2-1.i686/src/caja-1.18.2/src/file-manager/fm-marshal.list:1) */
 void
 fm_marshal_BOOLEAN__VOID (GClosure     *closure,
                           GValue       *return_value G_GNUC_UNUSED,
@@ -61,9 +61,9 @@ fm_marshal_BOOLEAN__VOID (GClosure     *closure,
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
                                                   gpointer     data2);
-  register GMarshalFunc_BOOLEAN__VOID callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__VOID callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -87,7 +87,7 @@ fm_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:OBJECT,OBJECT (/usr/src/ports/caja/caja-1.10.3-1.x86_64/src/caja-1.10.3/src/file-manager/fm-marshal.list:2) */
+/* VOID:OBJECT,OBJECT (/usr/src/ports/caja/caja-1.18.2-1.i686/src/caja-1.18.2/src/file-manager/fm-marshal.list:2) */
 void
 fm_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                 GValue       *return_value G_GNUC_UNUSED,
@@ -100,9 +100,9 @@ fm_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
